@@ -1,6 +1,19 @@
-from PyQt5.QtCore import QTimer, QObject, pyqtSignal, pyqtSlot
+from PyQt5.QtCore import QTimer, QObject, pyqtSignal, pyqtSlot, QSettings
 from stdcom import *
 
+"""
+    This is where Stec QObject are kept, this are not QWidgets
+"""
+class VSettings(QSettings):
+    """
+    Used to save setup data
+    """
+    def __init__(self, project : str = "stec-opcua"):
+        """
+        :param project:   default is "stec-opc" Should be the Project you or instance of the Project
+        """
+        super().__init__( project, QSettings.IniFormat)
+
 
 class stdcomPyQt(QObject):
     """
@@ -10,6 +23,8 @@ class stdcomPyQt(QObject):
 
 
     sigNewData = pyqtSignal(str, list)
+    sigNewDesc = pyqtSignal(str, str)
+
     sigNames = pyqtSignal(list)
     sigConnect = pyqtSignal()
     sigNoConnect = pyqtSignal()
@@ -23,11 +38,16 @@ class stdcomPyQt(QObject):
 
     # this is a duplicate, but it allows us to stay running if the Links to Multiverse is down..
     liveData = {}
+    liveDesc = {}
+
     timer = None
-    MultiverseHostname = "192.168.199.7"
+    MultiverseHostname = "192.168.199.245"
     MultiversePort = 4897
 
     def __init__(self, uiparent: QObject = None):
+        """
+        :param uiparent: QObject of the parent or None
+        """
         if uiparent is not None:
             super().__init__(uiparent)
         else:
@@ -58,7 +78,6 @@ class stdcomPyQt(QObject):
         return None
 
     def writeValues(self, Name: str, Data: list):
-
         """
         WritesValues to multiverse if subcription is made, or local data is ~/ is the prefix
             :Name: The name of the subscription, if ~/ is the prefix, then data is local.
@@ -74,7 +93,7 @@ class stdcomPyQt(QObject):
 
             # allow the system to operate without Multiverse
             else:
-                self.sigNewData.emit(Name, Data())
+                self.sigNewData.emit(Name, Data)
 
     def subscribe(self, Name: str):
         """
@@ -113,6 +132,8 @@ class stdcomPyQt(QObject):
                 self.cBridge.RemoveSub(Name)
 
     def AddValues(self, sub):
+
+
         """
         Internal use, updates makes and notfies by signal data has changed for a subcription
             :sigNewData.emit: Name, Data
@@ -120,13 +141,27 @@ class stdcomPyQt(QObject):
         self.liveData.update({sub.Name(): sub.Data()})
         self.sigNewData.emit(sub.Name(), sub.Data())
 
+    def AddDesc(self, sub):
+        """
+        Internal use, updates makes and notfies by signal data has changed for a subcription
+            :sigNewData.emit: Name, Data
+        """
+
+
+        d = sub.Data()
+
+        if len(d) >= 1  :
+            desc = str (d[0])
+            self.liveDesc.update({sub.Name() : desc})
+            self.sigNewDesc.emit(sub.Name(), desc)
+
 
     def AddNames(self, values):
         """
         Internal use tell when a new name is found, with emit
             : sigNames.emit: list[str] of new names entering the picture that can be subscribed to
         """
-        print("AddNames")
+
         self.sigNames.emit(values)
 
     def ConnectSocket(self, v):
@@ -167,7 +202,7 @@ class stdcomPyQt(QObject):
             self.cBridge = stdcom(self.MultiverseHostname, self.MultiversePort, self.ConnectSocket, None, None,
                                   self.ConnectionError)
 
-            self.cBridge.SetCallbacks(self.AddValues, self.AddNames)
+            self.cBridge.SetCallbacks(self.AddValues, self.AddNames, self.AddDesc)
             self.cBridge.NamesOn()  # tell the communication class to tu
             self.sigNames.connect(self.NewLiveTags)
             self.sigConnect.emit()
@@ -220,16 +255,57 @@ class stdcomPyQt(QObject):
 
 if __name__ == "__main__":
 
+
+    class stdcomClientPyQt(QObject):
+
+        cBridge = None
+
+        def __init__(self, cBridge : stdcomPyQt = None,  uiparent: QObject = None):
+
+            self.cBridge = cBridge
+            """
+               :param uiparent: QObject of the parent or None
+            """
+            if uiparent is not None:
+                super().__init__(uiparent)
+            else:
+                super().__init__()
+
+            self.cBridge.sigNames.connect(self.slotNames)
+            self.cBridge.sigNewData.connect(self.slotNewData)
+            self.cBridge.sigNewDesc.connect(self.slotNewDesc)
+
+            print("Connected")
+
+        @pyqtSlot(str, list )
+        def slotNewData(self, name, data):
+            print("New Data",name, ":", data )
+
+        @pyqtSlot(str, str)
+        def slotNewDesc(self, name, desc):
+            print("New Desc", name, ":", desc)
+
+        @pyqtSlot( list)
+        def slotNames(self, names : list):
+            print("New Name", names)
+            for name in names :
+                self.cBridge.subscribe(name)
+
+
+
     from PyQt5.QtCore import QCoreApplication
     import sys
 
     if "--version" in sys.argv:
-        print("1.2.0")
+        print("1.5.00")
         sys.exit()
 
     app = QCoreApplication(sys.argv)
     w = stdcomPyQt()
+    client = stdcomClientPyQt(w)
     w.LoadcBridge()
+
+
     app.exec_()
     w.terminate()
     sys.exit(0)
